@@ -8,11 +8,12 @@ sub startup ($self) {
   my $config = $self->plugin('NotYAMLConfig');
 
   $self->plugin(
-    'Sentry',
+    'SentrySDK',
     {
       dsn     => 'http://b61a335479ff48529d773343287bcdad@localhost:9000/2',
       release => '1.0.0',
       dist    => '12345',
+      traces_sample_rate => 0.1,
     }
   );
 
